@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1995-08-10
- * modified: 2006-01-06
+ * modified: 2006-12-11
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -54,7 +54,7 @@
 @implementation App
 
 /*
- * modified: 2005-07-22
+ * modified: 2006-12-11
  * Initializes the defaults.
  */
 + (void)initialize
@@ -63,11 +63,7 @@
     [registrationDict setObject:@"." forKey:@"NSDecimalSeparator"];
 
     /* General Preferences defaults */
-#ifdef __APPLE__
-    [registrationDict setObject:@"NO"  forKey:@"doCaching"];
-#else
     [registrationDict setObject:@"YES" forKey:@"doCaching"];
-#endif
     [registrationDict setObject:@"0"   forKey:@"unit"];
     [registrationDict setObject:@"NO"  forKey:@"removeBackups"];
     [registrationDict setObject:@"NO"  forKey:@"expertMode"];
