@@ -1752,9 +1752,9 @@
                 for (k=0; k < sPairsCnt; k++)
                 {
                     if ((startIs[si] < listCnt &&
-                        [gj identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
-                        (endIs[si] < listCnt &&
-                         [gj identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
+                        [gj identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
+                         // || (endIs[si] < listCnt &&
+                         // [gj identicalWith:[[ng list] objectAtIndex:endIs[si]]])
                     {
                         [splitListUg removeObjectAtIndex:j];
                         /* korrect all uStartIs behind j */
@@ -1880,9 +1880,9 @@
                                 for (l=0; l < sPairsCnt; l++)
                                 {
                                     if ((startIs[si] < listCnt &&
-                                         [gkn identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
-                                        (endIs[si] < listCnt &&
-                                         [gkn identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
+                                         [gkn identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
+                                    // || (endIs[si] < listCnt &&
+                                    // [gkn identicalWith:[[ng list] objectAtIndex:endIs[si]]])
                                     {
                                         gknIsDouble = YES;
                                         break;
@@ -1966,9 +1966,9 @@
                                 for (l=0; l < sPairsCnt; l++)
                                 {
                                     if ((startIs[si] < listCnt &&
-                                         [gkp identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
-                                        (endIs[si] < listCnt &&
-                                         [gkp identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
+                                         [gkp identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
+                                    // || (endIs[si] < listCnt &&
+                                    // [gkp identicalWith:[[ng list] objectAtIndex:endIs[si]]])
                                     {
                                         gkpIsDouble = YES;
                                         break;
